{% extends "admin/change_form.html" %}

{% load i18n %}

{% block extrahead %}{{ block.super }}
<style>
	.submit-row {display:none;}
	.submit-row-custom {display:block;}
</style>
{% endblock %}

{% block after_related_objects %}{{ block.super }}
<div class="submit-row submit-row-custom">
	<input type="submit" value="{% trans 'Import Key' %}" class="default" name="_save" />
</div>
{% endblock %}